@@ -5,9 +5,10 @@ from .cluster import ClusterProvider
 from .docker import DockerProvider
 from .kubernetes import KubernetesProvider
 from .api import ApiProvider
+from .errors import TaskCreationError, ProviderError
 
 
-def get_cluster_provider(type, args = { }):
+def get_cluster_provider(type, **args):
     if type == 'docker':
         return DockerProvider(args)
     elif type == 'kubernetes':
