@@ -8,8 +8,9 @@ from .errors import TaskError, TaskNotFoundError
 from .task import Task
 from .remote_task import RemoteTask
 from .definition import TaskDefinition
+from .decorator import task
 
 from .flow import Flow
-from .ops import join
+from .ops import join, gather
 
 from .components.rpc import rpc
