@@ -1,6 +1,7 @@
 from __future__ import annotations
 import asyncio
 from concurrent.futures import Future
+from cowait.types import type_from_description
 from .errors import TaskError
 from .definition import TaskDefinition
 from .status import WAIT, WORK, FAIL, DONE
@@ -22,10 +23,14 @@ class RemoteTask(TaskDefinition):
     def __await__(self):
         return self.awaitable.__await__()
 
-    def destroy(self):
+    @property
+    def done(self) -> bool:
+        return self.future.done()
+
+    def destroy(self) -> None:
         self.cluster.destroy(self.id)
 
-    def set_status(self, status):
+    def set_status(self, status: str) -> None:
         # sanity checks
         if self.status == FAIL and status == DONE:
             raise RuntimeError('Cant complete a failed task')
@@ -36,19 +41,23 @@ class RemoteTask(TaskDefinition):
         # update status
         self.status = status
 
-    def set_error(self, error):
+    def set_error(self, error: str) -> None:
         self.set_status(FAIL)
         self.error = error
         if not self.future.done():
             self.future.set_exception(TaskError(error))
 
-    def set_result(self, result):
+    def set_result(self, result: any, result_type: any = 'any') -> None:
+        # unpack type & deserialize result
+        result_type = type_from_description(result_type)
+        result = result_type.deserialize(result)
+
         self.set_status(DONE)
         self.result = result
         if not self.future.done():
             self.future.set_result(result)
 
-    async def wait_for_init(self, timeout=30):
+    async def wait_for_init(self, timeout=30) -> None:
         if self.status != WAIT:
             raise RuntimeError(f'Cant await task with status {self.status}')
 
@@ -68,9 +77,12 @@ class RemoteTask(TaskDefinition):
             slept += interval
 
     async def call(self, method, args={}):
-        if self.status != WORK:
+        if self.status == WAIT:
+            await self.wait_for_init()
+        elif self.status != WORK:
             raise RuntimeError(
-                f'RPC is only available when status = WORK, was {self.status}')
+                f'RPC is only available when status = WORK, was {self.status}. '
+                f'Attempted to call {method}')
 
         return await self.conn.rpc.call(method, args)
 
@@ -79,6 +91,8 @@ class RemoteTask(TaskDefinition):
         await self.call('stop')
 
     def __getattr__(self, method):
-        async def magic_rpc(**kwargs):
+        async def magic_rpc(*args, **kwargs):
+            if len(args) > 0:
+                raise TypeError('Positional arguments are not supported for RPC methods')
             return await self.call(method, kwargs)
         return magic_rpc
