@@ -9,23 +9,26 @@ CURRENT_TASK = None
 
 
 class Task(TaskDefinition):
-    """
-    Task base class.
-    """
-
     def __init__(
         self,
-        taskdef,
-        cluster,
-        node,
+        **inputs,
     ):
-        kwargs = taskdef.serialize()
+        """
+        Creates a new instance of the task. Pass inputs as keyword arguments.
+        """
+        # we are using **inputs keyword arguments so that the documentation will be
+        # more helpful when invoking subtasks.
+        kwargs = inputs['taskdef'].serialize()
         super().__init__(**kwargs)
-        self.node = node
-        self.cluster = cluster
+        self.node = inputs['node']
+        self.cluster = inputs['cluster']
         self.subtasks = TaskManager(self)
         self.rpc = RpcComponent(self)
 
+        # the base task constructor only takes 3 arguments.
+        if len(inputs) != 3:
+            raise RuntimeError('Invalid task constructor call')
+
     def __new__(cls, *args, **inputs):
         global CURRENT_TASK
         if CURRENT_TASK is None:
@@ -37,6 +40,10 @@ class Task(TaskDefinition):
         else:
             # we already have a task.
             # spawn a remote task and return it.
+
+            if len(args) > 0:
+                raise RuntimeError('Tasks do not accept positional arguments')
+
             return CURRENT_TASK.spawn(cls, **inputs)
 
     def __str__(self) -> str:
@@ -77,6 +84,7 @@ class Task(TaskDefinition):
         inputs: dict = {},
         meta: dict = {},
         env: dict = {},
+        volumes: dict = {},
         cpu: str = '0',
         memory: str = '0',
         owner: str = '',
@@ -108,6 +116,10 @@ class Task(TaskDefinition):
             cpu=cpu,
             memory=memory,
             owner=owner,
+            volumes={
+                **self.volumes,
+                **volumes,
+            },
             inputs={
                 **inputs,
                 **kwargs,
