@@ -9,11 +9,21 @@ class UtilityTask(Task):
     """
 
     def __init__(self, taskdef, cluster, node):
-        super().__init__(taskdef, cluster, node)
+        super().__init__(
+            taskdef=taskdef,
+            cluster=cluster,
+            node=node,
+        )
         # store taskdef for later comparison
         self.taskdef = taskdef
 
-    async def run(self, **inputs):
+    async def run(
+        self,
+        child: bool = False,
+        error: bool = False,
+        child_error: bool = False,
+        **inputs
+    ):
         # dump task information to stdout
         print(json.dumps({
             'taskdef': self.taskdef.serialize(),
@@ -21,8 +31,14 @@ class UtilityTask(Task):
         }))
 
         # create a child
-        if inputs.get('child', False):
-            await self.spawn('cowait.test.tasks.utility_task')
+        if child or child_error:
+            print('spawn child')
+            await self.spawn(
+                'cowait.test.tasks.utility_task',
+                inputs={'error': child_error})
+
+        if error:
+            raise RuntimeError('Caused test error')
 
         # run forever
         if inputs.get('forever', False):
